# sentineltools

[![PyPI version](https://badge.fury.io/py/sentineltools.svg)](https://badge.fury.io/py/sentineltools)

# Installation
Sentinel Tools requires torch but as direct installs are not allowed in pypi, grab the version you want to use. This package should work with mostly any. But it was built with the intention to use the pip install below:
pip install torch torchvision torchaudio --index-url https://download.pytorch.org/whl/cu118
then
pip install sentineltools

**sentineltools** is a collection of a bunch of tools that I wanted to have for any project I make. It is designed for windows

## Features

- **Feature1**: brief description

## Examples

```python

```